From 4bd960b10d9f32cb8a82a0718caaa005768c107c Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Wed, 24 Oct 2012 06:07:53 -0400
Subject: [PATCH] Merged revisions 3557-3594 from 3.0.5 stable branch.

---
 server/plugins-available/apache2_plugin.inc.php |   16 +++++++++-------
 1 files changed, 9 insertions(+), 7 deletions(-)

diff --git a/server/plugins-available/apache2_plugin.inc.php b/server/plugins-available/apache2_plugin.inc.php
index a1820d9..182a738 100644
--- a/server/plugins-available/apache2_plugin.inc.php
+++ b/server/plugins-available/apache2_plugin.inc.php
@@ -115,8 +115,8 @@
 		$csr_file = $ssl_dir.'/'.$domain.'.csr';
 		$crt_file = $ssl_dir.'/'.$domain.'.crt';
 
-		//* Create a SSL Certificate
-		if($data['new']['ssl_action'] == 'create') {
+		//* Create a SSL Certificate, but only if this is not a mirror server.
+		if($data['new']['ssl_action'] == 'create' && $conf['mirror_server_id'] == 0) {
 			
 			$this->ssl_certificate_changed = true;
 			
@@ -1354,7 +1354,7 @@
 				$app->system->web_folder_protection($data['new']['document_root'],false);
 				$app->system->file_put_contents($data['new']['document_root'].'/.htpasswd_stats',$htp_file);
 				$app->system->web_folder_protection($data['new']['document_root'],true);
-				$app->system->chmod($data['new']['document_root'].'/.htpasswd_stats',0755);
+				$app->system->chmod($data['new']['document_root'].'/.htpasswd_stats',0750);
 				unset($htp_file);
 			}
 		}
@@ -1715,8 +1715,8 @@
 		
 		//* Create empty .htpasswd file, if it does not exist
 		if(!is_file($folder_path.'.htpasswd')) {
-			touch($folder_path.'.htpasswd');
-			$app->system->chmod($folder_path.'.htpasswd',0755);
+			$app->system->touch($folder_path.'.htpasswd');
+			$app->system->chmod($folder_path.'.htpasswd',0750);
 			$app->system->chown($folder_path.'.htpasswd',$website['system_user']);
 			$app->system->chgrp($folder_path.'.htpasswd',$website['system_group']);
 			$app->log('Created file '.$folder_path.'.htpasswd',LOGLEVEL_DEBUG);
@@ -1770,7 +1770,7 @@
             unset($old_content);
             
             $app->system->file_put_contents($folder_path.'.htaccess',$ht_file);
-			$app->system->chmod($folder_path.'.htaccess',0755);
+			$app->system->chmod($folder_path.'.htaccess',0750);
 			$app->system->chown($folder_path.'.htaccess',$website['system_user']);
 			$app->system->chgrp($folder_path.'.htaccess',$website['system_group']);
 			$app->log('Created/modified file '.$folder_path.'.htaccess',LOGLEVEL_DEBUG);
@@ -1932,7 +1932,7 @@
             }
             
             $app->system->file_put_contents($new_folder_path.'.htaccess',$ht_file);
-			$app->system->chmod($new_folder_path.'.htaccess',0755);
+			$app->system->chmod($new_folder_path.'.htaccess',0750);
 			$app->system->chown($new_folder_path.'.htaccess',$website['system_user']);
 			$app->system->chgrp($new_folder_path.'.htaccess',$website['system_group']);
 			$app->log('Created/modified file '.$new_folder_path.'.htaccess',LOGLEVEL_DEBUG);
@@ -2118,6 +2118,8 @@
 	 * @param string $pwd      The password-hash of the user
 	 */
 	private function _writeHtDigestFile($filename, $username, $authname, $pwdhash ) {
+		global $app;
+		
 		$changed = false;
 		if(is_file($filename) && !is_link($filename)) {
 			$in = fopen($filename, 'r');

--
Gitblit v1.9.1